@@ -6,25 +6,23 @@ from threading import Lock
 import amqp
 import sys
 
-from synergy.conf import settings
+from synergy.conf import settings, context
 from synergy.system.decorator import thread_safe
-from synergy.conf.process_context import ProcessContext
-from synergy.conf.mq_queue_context import MqQueueContext
 
 
 class SynergyAware(object):
     def __init__(self, name):
         self.name = name
-        if name in ProcessContext.CONTEXT:
-            self.routing_key = ProcessContext.get_routing(name)
-            self.exchange = ProcessContext.get_exchange(name)
-            self.queue = ProcessContext.get_queue(name)
-        elif name in MqQueueContext.CONTEXT:
-            self.routing_key = MqQueueContext.get_routing(name)
-            self.exchange = MqQueueContext.get_exchange(name)
-            self.queue = name
+        if name in context.process_context:
+            the_context = context.process_context
+        elif name in context.mq_queue_context:
+            the_context = context.mq_queue_context
         else:
-            raise ValueError('Unknown name %s. Unable to retrieve amqp settings.' % name)
+            raise ValueError(f'Unknown name {name}. Unable to retrieve amqp settings.')
+
+        self.routing_key = the_context[name].mq_routing_key
+        self.exchange = the_context[name].mq_exchange
+        self.queue = the_context[name].mq_queue
 
 
 class Connection(object):
@@ -48,11 +46,12 @@ class Connection(object):
 
     def connect(self):
         self.connection = amqp.Connection(
-            host='%s:%s' % (self.db_host, self.port),
+            host='{0}:{1}'.format(self.db_host, self.port),
             userid=self.user_id,
             password=self.password,
             virtual_host=self.vhost
         )
+        self.connection.connect()
 
     def close(self):
         if hasattr(self, 'connection') and self.connection:
@@ -114,13 +113,12 @@ class Consumer(SynergyAware):
 
     def wait(self, timeout=None):
         while self.is_running:
-            channel_id, method_sig, args, content = \
-                self.connection.connection._wait_multiple(channels={self.channel.channel_id: self.channel},
-                                                          allowed_methods=None,
-                                                          timeout=timeout)
-            self.channel.dispatch_method(method_sig, args, content)
+            self.connection.connection.blocking_read(timeout=timeout)
 
     def dispatch(self, message):
+        if isinstance(message.body, bytes):
+            message.body = message.body.decode('utf-8')
+
         decoded = json.loads(message.body)
         message.body = decoded['data']
         if self.callback is not None:
@@ -139,6 +137,7 @@ class Consumer(SynergyAware):
             self.channel.basic_reject(delivery_tag=tag, requeue=False)
 
     def register(self, callback):
+        assert callable(callback)
         self.callback = callback
 
     def unregister(self):
@@ -178,14 +177,20 @@ class Publisher(SynergyAware):
             self.close()
 
     def close(self):
-        if hasattr(self, 'channel') and self.channel:
+        try:
             self.channel.close()
+        except:
+            pass
 
-        if hasattr(self, 'connection') and self.connection:
+        try:
             self.connection.close()
+        except:
+            pass
 
-        if hasattr(self, 'parent_pool') and self.parent_pool:
+        try:
             del self.parent_pool
+        except:
+            pass
 
 
 class _Pool(object):
@@ -217,11 +222,8 @@ class _Pool(object):
             try:
                 publisher.close()
             except Exception as e:
-                if not suppress_logging:
-                    self.logger.error('Exception on closing Flopsy Publisher %s: %s' % self.name, exc_info=True)
-                else:
-                    self.logger.info('Error while closing Flopsy Publisher for %s: %s. Full trace suppressed.'
-                                     % (self.name, str(e)))
+                self.logger.error(f'Exception on closing Flopsy Publisher {self.name}: {e}',
+                                  exc_info=not suppress_logging)
         self.publishers.clear()
 
 
@@ -248,7 +250,7 @@ class PublishersPool(object):
 
     def reset_all(self, suppress_logging=False):
         """ iterates thru the list of established connections and resets them by disconnecting and reconnecting """
-        pool_names = self.pools.keys()
+        pool_names = list(self.pools)
         for name in pool_names:
             self.reset(name, suppress_logging)
 
@@ -256,24 +258,21 @@ class PublishersPool(object):
         """ resets established connection by disconnecting and reconnecting """
         self._close(name, suppress_logging)
         self.get(name)
-        self.logger.info('Reset Flopsy Pool for %s' % name)
+        self.logger.info(f'Reset Flopsy Pool for {name}')
 
     def _close(self, name, suppress_logging):
         """ closes one particular pool and all its amqp amqp connections """
         try:
-            pool_names = self.pools.keys()
+            pool_names = list(self.pools)
             if name in pool_names:
                 self.pools[name].close()
                 del self.pools[name]
         except Exception as e:
-            if not suppress_logging:
-                self.logger.error('Exception on closing Flopsy Pool for %s' % name, exc_info=True)
-            else:
-                self.logger.info('Error while closing Flopsy Pool for %s: %s. Full trace suppressed.' % (name, str(e)))
+            self.logger.error(f'Exception on closing Flopsy Pool for {name}: {e}', exc_info=not suppress_logging)
 
     def close(self, suppress_logging=False):
         """ iterates thru all publisher pools and closes them """
-        pool_names = self.pools.keys()
+        pool_names = list(self.pools)
         for name in pool_names:
             self._close(name, suppress_logging)
 
@@ -289,10 +288,10 @@ def purge_mq_queue(mq_queue_name):
         conn = Connection()
         chan = conn.connection.channel()
         n = chan.queue_purge(mq_queue_name)
-        sys.stdout.write('Purged %s messages from %s queue\n' % (n, mq_queue_name))
+        sys.stdout.write(f'Purged {n} messages from {mq_queue_name} queue\n')
         return n
     except Exception as e:
-        sys.stderr.write('Unable to purge %s due to %s\n' % (mq_queue_name, str(e)))
+        sys.stderr.write(f'Unable to purge {mq_queue_name} due to {e}\n')
     finally:
         if chan is not None:
             chan.close()
