@@ -6,27 +6,16 @@ import functools
 import traceback
 
 
-def current_process_aware(class_method):
-    """
-    this decorator is used in ProcessContext to handle case where callers have no notion of the process they run within
-    :param class_method: method to wrap
-    """
-
-    @functools.wraps(class_method)
-    def _class_method(cls, process_name):
-        if process_name is None:
-            process_name = cls.get_current_process()
-        return class_method(cls, process_name)
-
-    return _class_method
-
-
 def thread_safe(method):
-    """ wraps function with lock acquire/release cycle
+    """ wraps method with lock acquire/release cycle
      decorator requires class instance to have field self.lock of type threading.Lock or threading.RLock """
 
     @functools.wraps(method)
     def _locker(self, *args, **kwargs):
+        assert hasattr(self, 'lock'), \
+            'thread_safe decorator applied to method {0}.{1}: missing required field {0}.lock'\
+            .format(self.__class__.__name__, method.__name__)
+
         try:
             self.lock.acquire()
             return method(self, *args, **kwargs)
@@ -34,7 +23,7 @@ def thread_safe(method):
             try:
                 self.lock.release()
             except:
-                sys.stderr.write('Exception on releasing lock at method %s' % method.__name__)
+                sys.stderr.write(f'Exception on releasing lock at method {method.__name__}')
                 traceback.print_exc(file=sys.stderr)
 
     return _locker
@@ -56,12 +45,15 @@ def with_reconnect(func):
 
     @functools.wraps(func)
     def _reconnector(*args, **kwargs):
-        for _ in xrange(20):
+        e = None
+        for _ in range(20):
             try:
                 return func(*args, **kwargs)
-            except AutoReconnect:
+            except AutoReconnect as ar:
                 time.sleep(0.250)
-        raise
+                e = ar
+        if e:
+            raise e
 
     return _reconnector
 
@@ -82,25 +74,3 @@ def singleton(cls):
         return instances[cls]
 
     return get_instance
-
-
-def base_model_derived(base_model_class):
-    """ wraps setter/getter with a convertor to/from BaseModel and dict """
-
-    def actual_decorator(method):
-        @functools.wraps(method)
-        def wrapper(self, *args):
-            if args:
-                # we are in the setter
-                if isinstance(args[0], base_model_class):
-                    method(self, args[0].document)
-                else:
-                    method(self, *args)
-            else:
-                # we are in the getter
-                field_value = method(self)
-                if isinstance(field_value, dict):
-                    return base_model_class(field_value)
-                return field_value
-        return wrapper
-    return actual_decorator
