@@ -13,25 +13,19 @@ class FootprintCalculator(object):
     def __init__(self):
         self.pid = os.getpid()
 
-    def group(self, number):
-        """ method formats number and inserts thousands separators """
-        s = '%d' % number
-        groups = []
-        while s and s[-1].isdigit():
-            groups.append(s[-3:])
-            s = s[:-3]
-        return s + '\''.join(reversed(groups))
-
-    def get_snapshot_as_list(self):
+    @property
+    def document(self):
         ps = psutil.Process(self.pid)
-        return (self.group(ps.get_memory_info()[0]),
-                self.group(ps.get_memory_info()[1]),
-                '%02d' % ps.get_cpu_percent(),
-                self.group(psutil.phymem_usage().free),
-                self.group(psutil.virtmem_usage().free))
+        # '{:,}'.format(number) returns a string with coma as a thousand-separator
+        return {'memory_rss': '{:,}'.format(ps.memory_info()[0]),
+                'memory_vms': '{:,}'.format(ps.memory_info()[1]),
+                'cpu_utilization': '{0:02.0f}'.format(ps.cpu_percent()),
+                'mem_virtual_free': '{:,}'.format(psutil.virtual_memory().free),
+                'mem_swap_free': '{:,}'.format(psutil.swap_memory().free)}
 
     def get_snapshot(self):
-        resp = 'Footprint: RSS=%r VMS=%r CPU=%r; Available: PHYS=%r VIRT=%r' % self.get_snapshot_as_list()
+        resp = 'Footprint: RSS={memory_rss} VMS={memory_vms} CPU={cpu_utilization}; ' \
+               'Available: PHYS={mem_virtual_free} VIRT={mem_swap_free}'.format(**self.document)
         return resp
 
 
@@ -55,14 +49,14 @@ class Tracker(object):
 class TrackerPair(object):
     def __init__(self, name, success='Success', failure='Failure'):
         self.name = name
-        self.success = Tracker(failure)
-        self.failure = Tracker(success)
+        self.success = Tracker(success)
+        self.failure = Tracker(failure)
 
     def increment_success(self, delta=1):
-        self.failure.increment(delta)
+        self.success.increment(delta)
 
     def increment_failure(self, delta=1):
-        self.success.increment(delta)
+        self.failure.increment(delta)
 
     def reset_tick(self):
         self.success.reset_tick()
@@ -73,13 +67,13 @@ class TrackerPair(object):
         self.failure.reset_24h()
 
     def to_string(self, tick_interval_seconds, show_header=True):
-        header = self.name + ' : ' + self.failure.name + '/' + self.success.name + '.' if show_header else ''
+        header = self.name + ' : ' + self.success.name + '/' + self.failure.name + '.' if show_header else ''
         return header + 'In last {0:d} seconds: {1:d}/{2:d}. In last 24 hours: {3:d}/{4:d}'.format(
             tick_interval_seconds,
-            self.failure.per_tick,
             self.success.per_tick,
-            self.failure.per_24h,
-            self.success.per_24h)
+            self.failure.per_tick,
+            self.success.per_24h,
+            self.failure.per_24h)
 
 
 class TickerThread(object):
@@ -93,7 +87,7 @@ class TickerThread(object):
         self.mark_24_hours = time.time()
         self.mark_footprint = time.time()
         self.footprint = FootprintCalculator()
-        self.timer = RepeatTimer(self.interval, self._run_tick_thread)
+        self.timer = RepeatTimer(self.interval, self._run_tick_thread, daemonic=True)
 
     def add_tracker(self, tracker):
         self.trackers[tracker.name] = tracker
@@ -124,7 +118,7 @@ class TickerThread(object):
             self.mark_24_hours = current_time
 
         tracker_outputs = []
-        for tracker_name, tracker in self.trackers.iteritems():
+        for tracker_name, tracker in self.trackers.items():
             tracker_outputs.append(tracker.to_string(self.interval))
             tracker.reset_tick()
             if do_24h_reset:
@@ -170,7 +164,8 @@ class UowAwareTracker(SimpleTracker):
     def __init__(self, logger):
         super(UowAwareTracker, self).__init__(logger)
         self.state = self.STATE_IDLE
-        self.per_job = 0
+        self.success_per_job = 0
+        self.failure_per_job = 0
         self.uow = None
         self.state_triggered_at = time.time()
 
@@ -178,15 +173,19 @@ class UowAwareTracker(SimpleTracker):
         super(UowAwareTracker, self)._run_tick_thread()
 
         if self.state == self.STATE_PROCESSING:
-            msg = 'State: %s for %d sec; %d in this uow;' \
-                  % (self.state, time.time() - self.state_triggered_at, self.per_job)
+            msg = 'State: {0} for {1:.2f} sec; Success/Failure {2}/{3} in this uow;'\
+                  .format(self.state, time.time() - self.state_triggered_at, self.success_per_job, self.failure_per_job)
         else:
-            msg = 'State: %s for %d sec;' % (self.state, time.time() - self.state_triggered_at)
+            msg = 'State: {0} for {1:.2f} sec;'.format(self.state, time.time() - self.state_triggered_at)
         self.logger.info(msg)
 
-    def increment(self):
+    def increment_success(self):
         self.tracker.increment_success()
-        self.per_job += 1
+        self.success_per_job += 1
+
+    def increment_failure(self):
+        self.tracker.increment_failure()
+        self.failure_per_job += 1
 
     def start_uow(self, uow):
         self.state = self.STATE_PROCESSING
@@ -194,15 +193,13 @@ class UowAwareTracker(SimpleTracker):
         self.state_triggered_at = time.time()
 
     def finish_uow(self):
-        self.logger.info('Success: unit_of_work %s in timeperiod %s; processed %d entries in %d seconds'
-                         % (self.uow.db_id,
-                            self.uow.timeperiod,
-                            self.per_job,
-                            time.time() - self.state_triggered_at))
+        self.logger.info('uow {0} at {1}: Success/Failure {2}/{3} entries in {4:.2f} seconds'.
+                         format(self.uow.db_id, self.uow.timeperiod,
+                                self.success_per_job, self.failure_per_job, time.time() - self.state_triggered_at))
         self.cancel_uow()
 
     def cancel_uow(self):
         self.state = self.STATE_IDLE
         self.uow = None
         self.state_triggered_at = time.time()
-        self.per_job = 0
+        self.success_per_job = 0
